@@ -21,12 +21,7 @@
 #' @details For \code{eta_sq()} (with \code{partial = FALSE}), due to
 #'   non-symmetry, confidence intervals are based on bootstrap-methods. In this
 #'   case, \code{n} indicates the number of bootstrap samples to be drawn to
-#'   compute the confidence intervals.
-#'   \cr \cr
-#'   For partial eta-squared (\code{eta_sq()} with \code{partial = TRUE}),
-#'   confidence intervals are based on \code{\link[apaTables]{get.ci.partial.eta.squared}}
-#'   and for omega-squared, confidence intervals are based on
-#'   \code{\link[MBESS]{conf.limits.ncf}}. Confidence intervals for partial
+#'   compute the confidence intervals. Confidence intervals for partial
 #'   omega-squared is also based on bootstrapping.
 #'
 #' @references Levine TR, Hullett CR (2002): Eta Squared, Partial Eta Squared, and Misreporting of Effect Size in Communication Research (\href{https://www.msu.edu/~levinet/eta\%20squared\%20hcr.pdf}{pdf})
@@ -46,12 +41,7 @@
 #' eta_sq(fit)
 #' omega_sq(fit)
 #' eta_sq(fit, partial = TRUE)
-#'
-#' # CI for eta-squared requires apaTables packages
-#' \dontrun{
-#' if (requireNamespace("apaTables", quietly = TRUE)) {
-#'   eta_sq(fit, partial = TRUE, ci.lvl = .8)
-#' }}
+#' eta_sq(fit, partial = TRUE, ci.lvl = .8)
 #'
 #' anova_stats(car::Anova(fit, type = 2))
 #'
@@ -72,7 +62,6 @@ eta_sq <- function(model, partial = FALSE, ci.lvl = NULL, n = 1000) {
     es = es
   )
 
-
   if (partial) {
     if (!is.null(ci.lvl) && !is.na(ci.lvl)) {
       x <- dplyr::bind_cols(x, peta_sq_ci(aov.sum = aov_stat_summary(model), ci.lvl = ci.lvl))
@@ -95,6 +84,8 @@ eta_sq <- function(model, partial = FALSE, ci.lvl = NULL, n = 1000) {
     TRUE ~ "effect.size"
   )
 
+  if (!is.null(attr(es, "stratum"))) x$stratum <- attr(es, "stratum")[1:nrow(x)]
+
   x
 }
 
@@ -142,6 +133,8 @@ omega_sq <- function(model, partial = FALSE, ci.lvl = NULL, n = 1000) {
     TRUE ~ "effect.size"
   )
 
+  if (!is.null(attr(es, "stratum"))) x$stratum <- attr(es, "stratum")[1:nrow(x)]
+
   x
 }
 
@@ -205,7 +198,12 @@ anova_stats <- function(model, digits = 3) {
 #' @importFrom rlang .data
 aov_stat <- function(model, type) {
   aov.sum <- aov_stat_summary(model)
-  aov_stat_core(aov.sum, type)
+  aov.res <- aov_stat_core(aov.sum, type)
+
+  if (tibble::has_name(aov.sum, "stratum"))
+    attr(aov.res, "stratum") <- aov.sum[["stratum"]]
+
+  aov.res
 }
 
 
@@ -219,10 +217,10 @@ aov_stat_summary <- function(model) {
 
   # check that model inherits from correct class
   # else, try to coerce to anova table
-  if (!inherits(model, c("aov", "anova", "anova.rms"))) model <- stats::anova(model)
+  if (!inherits(model, c("aov", "anova", "anova.rms", "aovlist"))) model <- stats::anova(model)
 
   # get summary table
-  aov.sum <- broom::tidy(model)
+  aov.sum <- as.data.frame(broom::tidy(model))
 
   # for mixed models, add information on residuals
   if (mm) {
@@ -303,19 +301,6 @@ aov_stat_core <- function(aov.sum, type) {
 #' @importFrom tibble tibble
 #' @importFrom purrr map_df
 omega_sq_ci <- function(aov.sum, ci.lvl = .95) {
-
-  if (!requireNamespace("MBESS", quietly = TRUE)) {
-    warning("Package `MBESS` needed to compute confidence intervals. Pleas install that package first.", call. = FALSE)
-
-    return(
-      tibble::tibble(
-        conf.low = NA,
-        conf.high = NA
-      )
-    )
-  }
-
-
   rows <- nrow(aov.sum) - 1
   df.den <- aov.sum[["df"]][rows + 1]
   N <- sum(aov.sum[["df"]]) + 1
@@ -324,16 +309,21 @@ omega_sq_ci <- function(aov.sum, ci.lvl = .95) {
     1:rows,
     function(.x) {
       df.num = aov.sum[.x, "df"]
+      test.stat <- aov.sum[.x, "statistic"]
 
-      ci <- MBESS::conf.limits.ncf(
-        F.value = aov.sum[.x, "statistic"],
-        conf.level = ci.lvl,
-        df.1 = df.num,
-        df.2 = df.den
-      )
+      if (!is.na(test.stat)) {
+        ci <- confint_ncg(
+          F.value = test.stat,
+          conf.level = ci.lvl,
+          df.1 = df.num,
+          df.2 = df.den
+        )
 
-      ci.low <- ci$Lower.Limit / (ci$Lower.Limit + N)
-      ci.high <- ci$Upper.Limit / (ci$Upper.Limit + N)
+        ci.low <- ci$Lower.Limit / (ci$Lower.Limit + N)
+        ci.high <- ci$Upper.Limit / (ci$Upper.Limit + N)
+      } else {
+        ci.low <- ci.high <- NA
+      }
 
       tibble::tibble(
         conf.low = ci.low,
@@ -347,18 +337,6 @@ omega_sq_ci <- function(aov.sum, ci.lvl = .95) {
 #' @importFrom tibble tibble
 #' @importFrom purrr map_df
 peta_sq_ci <- function(aov.sum, ci.lvl = .95) {
-
-  if (!requireNamespace("apaTables", quietly = TRUE)) {
-    warning("Package `apaTables` needed to compute confidence intervals. Pleas install that package first.", call. = FALSE)
-
-    return(
-      tibble::tibble(
-        conf.low = NA,
-        conf.high = NA
-      )
-    )
-  }
-
   rows <- nrow(aov.sum) - 1
   df.den <- aov.sum[["df"]][rows + 1]
 
@@ -366,18 +344,26 @@ peta_sq_ci <- function(aov.sum, ci.lvl = .95) {
     1:rows,
     function(.x) {
       df.num = aov.sum[.x, "df"]
+      test.stat <- aov.sum[.x, "statistic"]
 
-      ci <- apaTables::get.ci.partial.eta.squared(
-        F.value = aov.sum[.x, "statistic"],
-        df1 = df.num,
-        df2 = df.den,
-        conf.level = ci.lvl
-      )
+      if (!is.na(test.stat)) {
+        ci <- partial_eta_sq_ci(
+          F.value = test.stat,
+          df1 = df.num,
+          df2 = df.den,
+          conf.level = ci.lvl
+        )
 
-      tibble::tibble(
-        conf.low = ci$LL,
-        conf.high = ci$UL
-      )
+        tibble::tibble(
+          conf.low = ci$LL,
+          conf.high = ci$UL
+        )
+      } else {
+        tibble::tibble(
+          conf.low = NA,
+          conf.high = NA
+        )
+      }
     }
   )
 }
@@ -387,7 +373,7 @@ peta_sq_ci <- function(aov.sum, ci.lvl = .95) {
 #' @importFrom purrr map map_df
 #' @importFrom dplyr bind_cols mutate case_when pull
 #' @importFrom tibble tibble
-#' @importFrom stats anova formula
+#' @importFrom stats anova formula aov
 #' @importFrom sjmisc rotate_df
 es_boot_fun <- function(model, type, ci.lvl, n) {
 
@@ -398,28 +384,60 @@ es_boot_fun <- function(model, type, ci.lvl, n) {
     es = es
   )
 
-  mdata <- sjstats::model_frame(model)
-  mformula <- stats::formula(model)
 
-  # this is a bit sloppy, but I need to catch all exceptions here
-  # if we have a 1-way-anova, map() could return a column with
-  # one value per row (a vector). However, if the model has more
-  # covariates/factors, map() returns a list-colum with 3 values
-  # per row, which need to be spread into a 3 columns data frame.
+  # need special handling for repeated measure anova here
+
+  if (inherits(model, "aovlist")) {
+
+    mdata <- sjstats::model_frame(model)
+    mformula <- stats::formula(attr(model, "terms"))
+
+    # this is a bit sloppy, but I need to catch all exceptions here
+    # if we have a 1-way-anova, map() could return a column with
+    # one value per row (a vector). However, if the model has more
+    # covariates/factors, map() returns a list-colum with 3 values
+    # per row, which need to be spread into a 3 columns data frame.
+
+    es <- mdata %>%
+      bootstrap(n = n) %>%
+      dplyr::mutate(es = purrr::map(
+        .data$strap,
+        function(i) {
+          m <- stats::aov(mformula, data = i)
+          dat <- aov_stat(m, type = type)
+          sjmisc::rotate_df(as.data.frame(dat))
+        }
+      )) %>%
+      dplyr::pull(2) %>%
+      purrr::map_df(~ .x) %>%
+      boot_ci()
+
+  } else {
+
+    mdata <- sjstats::model_frame(model)
+    mformula <- stats::formula(model)
+
+    # this is a bit sloppy, but I need to catch all exceptions here
+    # if we have a 1-way-anova, map() could return a column with
+    # one value per row (a vector). However, if the model has more
+    # covariates/factors, map() returns a list-colum with 3 values
+    # per row, which need to be spread into a 3 columns data frame.
+
+    es <- mdata %>%
+      bootstrap(n = n) %>%
+      dplyr::mutate(es = purrr::map(
+        .data$strap,
+        function(i) {
+          m <- lm(mformula, data = i)
+          dat <- aov_stat(m, type = type)
+          sjmisc::rotate_df(as.data.frame(dat))
+        }
+      )) %>%
+      dplyr::pull(2) %>%
+      purrr::map_df(~ .x) %>%
+      boot_ci()
+  }
 
-  es <- mdata %>%
-    bootstrap(n = n) %>%
-    dplyr::mutate(es = purrr::map(
-      .data$strap,
-      function(i) {
-        m <- lm(mformula, data = i)
-        dat <- aov_stat(m, type = type)
-        sjmisc::rotate_df(as.data.frame(dat))
-      }
-    )) %>%
-    dplyr::pull(2) %>%
-    purrr::map_df(~ .x) %>%
-    boot_ci()
 
   x <- dplyr::bind_cols(x, es[, -1])
 
