@@ -113,15 +113,23 @@ mediation(m2, prob = .95)
 mediation(m2, typical = "mean", prob = .95) %>% print(digits = 4)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+icc(m4)
+
 icc(m5)
 
 ## ---- message=TRUE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-icc(m4, posterior = TRUE)
-
-icc(m5, posterior = TRUE)
+icc(m4, ppd = TRUE, re.form = ~(1 | cyl), prob = .5)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-icc(m5, posterior = TRUE) %>% print(prob = .95, digits = 3)
+# the "classical" ICC, not recommended for non-Gaussian
+icc(m3)
+
+# variance ratio based on posterior predictive distributions,
+# which is negative and hence obviously nonsense
+icc(m3, ppd = TRUE)
+
+# use median instead of mean
+icc(m3, ppd = TRUE, typical = "median")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 r2(m5)
